@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,7 +34,10 @@ use crate::runner::Value;
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct CliOptions {
     pub cacert_file: Option<String>,
+    pub client_cert_file: Option<String>,
+    pub client_key_file: Option<String>,
     pub color: bool,
+    pub connects_to: Vec<String>,
     pub compressed: bool,
     pub connect_timeout: Duration,
     pub cookie_input_file: Option<String>,
@@ -54,9 +57,11 @@ pub struct CliOptions {
     pub output: Option<String>,
     pub output_type: OutputType,
     pub proxy: Option<String>,
+    pub resolves: Vec<String>,
     pub retry: bool,
     pub retry_interval: Duration,
     pub retry_max_count: Option<usize>,
+    pub ssl_no_revoke: bool,
     pub test: bool,
     pub timeout: Duration,
     pub to_entry: Option<usize>,
@@ -105,6 +110,21 @@ pub fn app(version: &str) -> Command {
                 .help("CA certificate to verify peer against (PEM format)")
                 .num_args(1)
         )
+        .arg(
+            clap::Arg::new("client_cert_file")
+                .short('E')
+                .long("cert")
+                .value_name("CERTIFICATE[:PASSWORD]")
+                .help("Client certificate file and password")
+                .num_args(1)
+        )
+        .arg(
+            clap::Arg::new("client_key_file")
+                .long("key")
+                .value_name("KEY")
+                .help("Private key file name")
+                .num_args(1)
+        )
         .arg(
             clap::Arg::new("color")
                 .long("color")
@@ -127,6 +147,15 @@ pub fn app(version: &str) -> Command {
                 .value_parser(value_parser!(u64))
                 .num_args(1)
         )
+        .arg(
+            clap::Arg::new("connect_to")
+                .long("connect-to")
+                .value_name("HOST1:PORT1:HOST2:PORT2")
+                .help("For a request to the given HOST1:PORT1 pair, connect to HOST2:PORT2 instead")
+                .action(ArgAction::Append)
+                .number_of_values(1)
+                .num_args(1)
+        )
         .arg(
             clap::Arg::new("cookies_input_file")
                 .short('b')
@@ -277,6 +306,15 @@ pub fn app(version: &str) -> Command {
                 .help("Generate HTML report to DIR")
                 .num_args(1)
         )
+        .arg(
+            clap::Arg::new("resolve")
+                .long("resolve")
+                .value_name("HOST:PORT:ADDR")
+                .help("Provide a custom address for a specific host and port pair")
+                .action(ArgAction::Append)
+                .number_of_values(1)
+                .num_args(1)
+        )
         .arg(
             clap::Arg::new("retry")
                 .long("retry")
@@ -302,6 +340,12 @@ pub fn app(version: &str) -> Command {
                 .value_parser(value_parser!(i32).range(-1..))
                 .num_args(1)
         )
+        .arg(
+            clap::Arg::new("ssl_no_revoke")
+                .long("ssl-no-revoke")
+                .help("(Windows) This option tells Hurl to disable certificate revocation checks. WARNING: this option loosens the SSL security, and by using this flag you ask for exactly that.")
+                .action(ArgAction::SetTrue)
+        )
         .arg(
             clap::Arg::new("test")
                 .long("test")
@@ -348,6 +392,7 @@ pub fn app(version: &str) -> Command {
                 .long("variables-file")
                 .value_name("FILE")
                 .help("Define a properties file in which you define your variables")
+                .action(ArgAction::Append)
                 .num_args(1)
         )
         .arg(
@@ -366,6 +411,8 @@ pub fn app(version: &str) -> Command {
 }
 
 /// Parses command line options `matches`.
+// FIXME: disallow this clippy warning because of https://github.com/rust-lang/rust-clippy/issues/9766
+#[allow(clippy::manual_filter)]
 pub fn parse_options(matches: &ArgMatches) -> Result<CliOptions, CliError> {
     let cacert_file = match get::<String>(matches, "cacert_file") {
         None => None,
@@ -378,10 +425,33 @@ pub fn parse_options(matches: &ArgMatches) -> Result<CliOptions, CliError> {
             }
         }
     };
+    let client_cert_file = match get::<String>(matches, "client_cert_file") {
+        None => None,
+        Some(filename) => {
+            if !Path::new(&filename).is_file() {
+                let message = format!("File {} does not exist", filename);
+                return Err(CliError { message });
+            } else {
+                Some(filename)
+            }
+        }
+    };
+    let client_key_file = match get::<String>(matches, "client_key_file") {
+        None => None,
+        Some(filename) => {
+            if !Path::new(&filename).is_file() {
+                let message = format!("File {} does not exist", filename);
+                return Err(CliError { message });
+            } else {
+                Some(filename)
+            }
+        }
+    };
     let color = output_color(matches);
     let compressed = has_flag(matches, "compressed");
     let connect_timeout = get::<u64>(matches, "connect_timeout").unwrap();
     let connect_timeout = Duration::from_secs(connect_timeout);
+    let connects_to = get_strings(matches, "connect_to").unwrap_or_default();
     let cookie_input_file = get::<String>(matches, "cookies_input_file");
     let cookie_output_file = get::<String>(matches, "cookies_output_file");
     let fail_fast = !has_flag(matches, "fail_at_end");
@@ -431,6 +501,7 @@ pub fn parse_options(matches: &ArgMatches) -> Result<CliOptions, CliError> {
         OutputType::ResponseBody
     };
     let proxy = get::<String>(matches, "proxy");
+    let resolves = get_strings(matches, "resolve").unwrap_or_default();
     let retry = has_flag(matches, "retry");
     let retry_interval = get::<u64>(matches, "retry_interval").unwrap();
     let retry_interval = Duration::from_millis(retry_interval);
@@ -439,6 +510,7 @@ pub fn parse_options(matches: &ArgMatches) -> Result<CliOptions, CliError> {
         r if r == -1 => None,
         r => Some(r as usize),
     };
+    let ssl_no_revoke = has_flag(matches, "ssl_no_revoke");
     let timeout = get::<u64>(matches, "max_time").unwrap();
     let timeout = Duration::from_secs(timeout);
     let to_entry = get::<u32>(matches, "to_entry").map(|x| x as usize);
@@ -450,9 +522,12 @@ pub fn parse_options(matches: &ArgMatches) -> Result<CliOptions, CliError> {
 
     Ok(CliOptions {
         cacert_file,
+        client_cert_file,
+        client_key_file,
         color,
         compressed,
         connect_timeout,
+        connects_to,
         cookie_input_file,
         cookie_output_file,
         fail_fast,
@@ -470,9 +545,11 @@ pub fn parse_options(matches: &ArgMatches) -> Result<CliOptions, CliError> {
         output,
         output_type,
         proxy,
+        resolves,
         retry,
         retry_interval,
         retry_max_count,
+        ssl_no_revoke,
         test,
         timeout,
         to_entry,
@@ -512,31 +589,37 @@ fn variables(matches: &ArgMatches) -> Result<HashMap<String, Value>, CliError> {
         }
     }
 
-    if let Some(filename) = get::<String>(matches, "variables_file") {
-        let path = Path::new(&filename);
-        if !path.exists() {
-            return Err(CliError {
-                message: format!("Properties file {} does not exist", path.display()),
-            });
-        }
+    if let Some(filenames) = get_strings(matches, "variables_file") {
+        for f in filenames.iter() {
+            let path = Path::new(&f);
+            if !path.exists() {
+                return Err(CliError {
+                    message: format!("Properties file {} does not exist", path.display()),
+                });
+            }
 
-        let file = File::open(path).unwrap();
-        let reader = BufReader::new(file);
-        for (index, line) in reader.lines().enumerate() {
-            let line = match line {
-                Ok(s) => s,
-                Err(_) => {
-                    return Err(CliError {
-                        message: format!("Can not parse line {} of {}", index + 1, path.display()),
-                    });
+            let file = File::open(path).unwrap();
+            let reader = BufReader::new(file);
+            for (index, line) in reader.lines().enumerate() {
+                let line = match line {
+                    Ok(s) => s,
+                    Err(_) => {
+                        return Err(CliError {
+                            message: format!(
+                                "Can not parse line {} of {}",
+                                index + 1,
+                                path.display()
+                            ),
+                        });
+                    }
+                };
+                let line = line.trim();
+                if line.starts_with('#') || line.is_empty() {
+                    continue;
                 }
-            };
-            let line = line.trim();
-            if line.starts_with('#') || line.is_empty() {
-                continue;
+                let (name, value) = cli::parse_variable(line)?;
+                variables.insert(name.to_string(), value);
             }
-            let (name, value) = cli::parse_variable(line)?;
-            variables.insert(name.to_string(), value);
         }
     }
 
@@ -585,11 +668,12 @@ fn match_glob_files(matches: &ArgMatches) -> Result<Vec<String>, CliError> {
     Ok(filenames)
 }
 
-/// Returns a optional value of type `T` from the command line `matches` given the option `name`.
+/// Returns an optional value of type `T` from the command line `matches` given the option `name`.
 fn get<T: Clone + Send + Sync + 'static>(matches: &ArgMatches, name: &str) -> Option<T> {
     matches.get_one::<T>(name).cloned()
 }
 
+/// Returns an optional list of `String` from the command line `matches` given the option `name`.
 pub fn get_strings(matches: &ArgMatches, name: &str) -> Option<Vec<String>> {
     matches
         .get_many::<String>(name)
