@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,6 +31,9 @@ use super::response::*;
 use super::{Header, HttpError, Verbosity};
 use crate::cli::Logger;
 use crate::http::ContextDir;
+use base64::engine::general_purpose;
+use base64::Engine;
+use curl::easy::{List, SslOpt};
 use std::str::FromStr;
 use url::Url;
 
@@ -62,14 +65,8 @@ impl Client {
         }
     }
 
-    /// Executes an HTTP request, optionally follows redirection and returns a
+    /// Executes an HTTP request `request_spec`, optionally follows redirection and returns a
     /// list of pair of [`Request`], [`Response`].
-    ///
-    /// # Arguments
-    ///
-    /// * `request_spec` - A request specification
-    /// * `options`- Options for this execution
-    /// * `logger`- A logger
     pub fn execute_with_redirect(
         &mut self,
         request_spec: &RequestSpec,
@@ -117,14 +114,8 @@ impl Client {
         Ok(calls)
     }
 
-    /// Executes an HTTP request, without following redirection and returns a
+    /// Executes an HTTP request `request_spec`, without following redirection and returns a
     /// pair of [`Request`], [`Response`].
-    ///
-    /// # Arguments
-    ///
-    /// * `request_spec` - A request specification
-    /// * `options`- Options for this execution
-    /// * `logger`- A logger
     pub fn execute(
         &mut self,
         request_spec: &RequestSpec,
@@ -137,13 +128,29 @@ impl Client {
         // to capture HTTP request headers in libcurl `debug_function`. That's the only
         // way to get access to the outgoing headers.
         self.handle.verbose(true).unwrap();
+
+        if !options.connects_to.is_empty() {
+            let connects = to_list(&options.connects_to);
+            self.handle.connect_to(connects).unwrap();
+        }
+        if !options.resolves.is_empty() {
+            let resolves = to_list(&options.resolves);
+            self.handle.resolve(resolves).unwrap();
+        }
         self.handle.ssl_verify_host(!options.insecure).unwrap();
         self.handle.ssl_verify_peer(!options.insecure).unwrap();
         if let Some(cacert_file) = options.cacert_file.clone() {
             self.handle.cainfo(cacert_file).unwrap();
             self.handle.ssl_cert_type("PEM").unwrap();
         }
-
+        if let Some(client_cert_file) = options.client_cert_file.clone() {
+            self.handle.ssl_cert(client_cert_file).unwrap();
+            self.handle.ssl_cert_type("PEM").unwrap();
+        }
+        if let Some(client_key_file) = options.client_key_file.clone() {
+            self.handle.ssl_key(client_key_file).unwrap();
+            self.handle.ssl_cert_type("PEM").unwrap();
+        }
         if let Some(proxy) = options.proxy.clone() {
             self.handle.proxy(proxy.as_str()).unwrap();
         }
@@ -155,6 +162,8 @@ impl Client {
             .connect_timeout(options.connect_timeout)
             .unwrap();
 
+        self.set_ssl_options(options.ssl_no_revoke);
+
         let url = self.generate_url(&request_spec.url, &request_spec.querystring);
         self.handle.url(url.as_str()).unwrap();
         let method = &request_spec.method;
@@ -375,17 +384,9 @@ impl Client {
 
     /// Sets HTTP method.
     fn set_method(&mut self, method: &Method) {
-        match method {
-            Method::Get => self.handle.custom_request("GET").unwrap(),
-            Method::Post => self.handle.custom_request("POST").unwrap(),
-            Method::Put => self.handle.custom_request("PUT").unwrap(),
-            Method::Head => self.handle.custom_request("HEAD").unwrap(),
-            Method::Delete => self.handle.custom_request("DELETE").unwrap(),
-            Method::Connect => self.handle.custom_request("CONNECT").unwrap(),
-            Method::Options => self.handle.custom_request("OPTIONS").unwrap(),
-            Method::Trace => self.handle.custom_request("TRACE").unwrap(),
-            Method::Patch => self.handle.custom_request("PATCH").unwrap(),
-        }
+        self.handle
+            .custom_request(method.to_string().as_str())
+            .unwrap()
     }
 
     /// Sets HTTP headers.
@@ -402,11 +403,17 @@ impl Client {
                 list.append(format!("Content-Type: {}", s).as_str())
                     .unwrap();
             } else {
-                list.append("Content-Type:").unwrap(); // remove header Content-Type
+                // We remove default Content-Type headers added by curl because we want
+                // to explicitly manage this header.
+                // For instance, with --data option, curl will send a 'Content-type: application/x-www-form-urlencoded'
+                // header.
+                list.append("Content-Type:").unwrap();
             }
         }
 
         if request.get_header_values("Expect").is_empty() {
+            // We remove default Expect headers added by curl because we want
+            // to explicitly manage this header.
             list.append("Expect:").unwrap(); // remove header Expect
         }
 
@@ -420,7 +427,8 @@ impl Client {
         }
 
         if let Some(ref user) = options.user {
-            let authorization = base64::encode(user.as_bytes());
+            let user = user.as_bytes();
+            let authorization = general_purpose::STANDARD.encode(user);
             if request.get_header_values("Authorization").is_empty() {
                 list.append(format!("Authorization: Basic {}", authorization).as_str())
                     .unwrap();
@@ -488,6 +496,13 @@ impl Client {
         }
     }
 
+    /// Sets SSL options
+    fn set_ssl_options(&mut self, no_revoke: bool) {
+        let mut ssl_opt = SslOpt::new();
+        ssl_opt.no_revoke(no_revoke);
+        self.handle.ssl_options(&ssl_opt).unwrap();
+    }
+
     /// URL encodes parameters.
     fn url_encode_params(&mut self, params: &[Param]) -> String {
         params
@@ -590,6 +605,10 @@ impl Client {
         let mut arguments = vec!["curl".to_string()];
         arguments.append(&mut request_spec.curl_args(context_dir));
 
+        // We extract the last part of the arguments (the url) to insert it
+        // after all the options
+        let url = arguments.pop().unwrap();
+
         let cookies = all_cookies(&self.get_cookie_storage(), request_spec);
         if !cookies.is_empty() {
             arguments.push("--cookie".to_string());
@@ -603,6 +622,7 @@ impl Client {
             ));
         }
         arguments.append(&mut options.curl_args());
+        arguments.push(url);
         arguments.join(" ")
     }
 }
@@ -702,6 +722,13 @@ pub fn decode_header(data: &[u8]) -> Option<String> {
     }
 }
 
+/// Converts a list of [`String`] to a libcurl's list of strings.
+fn to_list(items: &[String]) -> List {
+    let mut list = List::new();
+    items.iter().for_each(|l| list.append(l).unwrap());
+    list
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
