@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -45,6 +45,13 @@ pub enum Method {
     Options,
     Trace,
     Patch,
+    Link,
+    Unlink,
+    Purge,
+    Lock,
+    Unlock,
+    Propfind,
+    View,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -97,6 +104,13 @@ impl fmt::Display for Method {
             Method::Options => "OPTIONS",
             Method::Trace => "TRACE",
             Method::Patch => "PATCH",
+            Method::Link => "LINK",
+            Method::Unlink => "UNLINK",
+            Method::Purge => "PURGE",
+            Method::Lock => "LOCK",
+            Method::Unlock => "UNLOCK",
+            Method::Propfind => "PROPFIND",
+            Method::View => "VIEW",
         };
         write!(f, "{}", value)
     }
