@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -45,7 +45,7 @@ fn query(reader: &mut Reader) -> ParseResult<Query> {
 
 fn selector(reader: &mut Reader) -> ParseResult<Selector> {
     choice(
-        vec![
+        &[
             selector_filter,
             selector_wildcard,
             selector_recursive_wildcard,
@@ -160,11 +160,7 @@ fn selector_object_key_bracket(reader: &mut Reader) -> Result<Selector, Error> {
 }
 
 fn selector_object_key(reader: &mut Reader) -> Result<Selector, Error> {
-    let end_delim = if reader.try_literal("['") {
-        "']".to_string()
-    } else if reader.try_literal(".") {
-        "".to_string()
-    } else {
+    if !reader.try_literal(".") {
         return Err(Error {
             pos: reader.state.pos.clone(),
             recoverable: true,
@@ -174,7 +170,7 @@ fn selector_object_key(reader: &mut Reader) -> Result<Selector, Error> {
         });
     };
 
-    let s = reader.read_while(|c| c.is_alphanumeric() || *c == '_');
+    let s = reader.read_while(|c| c.is_alphanumeric() || *c == '_' || *c == '-');
     if s.is_empty() {
         return Err(Error {
             pos: reader.state.pos.clone(),
@@ -184,10 +180,6 @@ fn selector_object_key(reader: &mut Reader) -> Result<Selector, Error> {
             },
         });
     }
-    if !end_delim.is_empty() {
-        literal(end_delim.as_str(), reader)?;
-    }
-
     Ok(Selector::NameChild(s))
 }
 
@@ -241,7 +233,7 @@ fn predicate(reader: &mut Reader) -> ParseResult<Predicate> {
 
 fn predicate_func(reader: &mut Reader) -> ParseResult<PredicateFunc> {
     choice(
-        vec![
+        &[
             equal_number_predicate_func,
             greater_than_predicate_func,
             greater_than_or_equal_predicate_func,
@@ -333,6 +325,18 @@ mod tests {
         );
         assert_eq!(query(&mut Reader::init("$.key")).unwrap(), expected_query);
 
+        let expected_query = Query {
+            selectors: vec![Selector::NameChild("profile-id".to_string())],
+        };
+        assert_eq!(
+            query(&mut Reader::init("$['profile-id']")).unwrap(),
+            expected_query
+        );
+        assert_eq!(
+            query(&mut Reader::init("$.profile-id")).unwrap(),
+            expected_query
+        );
+
         let expected_query = Query {
             selectors: vec![
                 Selector::NameChild("store".to_string()),
