@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,7 +33,7 @@ use hurl::report::canonicalize_filename;
 use hurl::runner;
 use hurl::runner::RunnerOptions;
 use hurl::runner::{HurlResult, RunnerError};
-use hurl::util::logger::BaseLogger;
+use hurl::util::logger::{BaseLogger, LoggerBuilder};
 use hurl_core::ast::{Pos, SourceInfo};
 use hurl_core::error::Error;
 use hurl_core::parser;
@@ -108,6 +108,7 @@ fn execute(
             logger.debug(format!("    fail fast: {}", cli_options.fail_fast).as_str());
             logger.debug(format!("    follow redirect: {}", cli_options.follow_location).as_str());
             logger.debug(format!("    insecure: {}", cli_options.insecure).as_str());
+
             if let Some(n) = cli_options.max_redirect {
                 logger.debug(format!("    max redirect: {}", n).as_str());
             }
@@ -130,8 +131,9 @@ fn execute(
                 );
             }
             let variables = cli_options.variables.clone();
+            let cookie_input_file = cli_options.cookie_input_file.clone();
             let runner_options = RunnerOptions::from(filename, current_dir, cli_options);
-            let mut client = http::Client::new(runner_options.cookie_input_file.clone());
+            let mut client = http::Client::new(cookie_input_file);
             let result = runner::run(
                 &hurl_file,
                 filename,
@@ -248,7 +250,14 @@ fn main() {
         } else {
             None
         };
-        let logger = Logger::new(color, verbose, filename, &content);
+        let mut builder = LoggerBuilder::new();
+        let logger = builder
+            .color(color)
+            .verbose(verbose)
+            .filename(filename)
+            .content(&content)
+            .build()
+            .unwrap();
 
         let hurl_result = execute(
             filename,
@@ -335,7 +344,7 @@ fn main() {
 
     if let Some(dir_path) = cli_options.html_dir {
         base_logger.debug(format!("Writing html report to {}", dir_path.display()).as_str());
-        let result = report::write_html_report(dir_path.clone(), hurl_results.clone());
+        let result = report::write_html_report(&dir_path, &hurl_results);
         unwrap_or_exit(result, EXIT_ERROR_UNDEFINED, &base_logger);
 
         for filename in filenames {
@@ -514,7 +523,7 @@ fn get_summary(duration: u128, hurl_results: &[HurlResult]) -> String {
 /// Returns status, version and HTTP headers from an HTTP `response`.
 fn get_status_line_headers(response: &Response, color: bool) -> String {
     let mut str = String::new();
-    let status_line = format!("HTTP/{} {}\n", response.version, response.status);
+    let status_line = format!("{} {}\n", response.version, response.status);
     let status_line = if color {
         format!("{}", status_line.green().bold())
     } else {
