@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,8 @@ use crate::http;
 use crate::runner::entry::get_entry_verbosity;
 use crate::runner::runner_options::RunnerOptions;
 use crate::runner::Value;
+use crate::util::logger::LoggerBuilder;
+use hurl_core::ast::VersionValue::VersionAnyLegacy;
 use hurl_core::ast::*;
 
 use super::core::*;
@@ -45,7 +47,8 @@ use super::entry;
 /// use hurl::http;
 /// use hurl::http::ContextDir;
 /// use hurl::runner;
-/// use hurl::runner::Value;
+/// use hurl::runner::{Value, RunnerOptionsBuilder, Verbosity};
+/// use hurl::util::logger::LoggerBuilder;
 ///
 /// // Parse Hurl file
 /// let filename = "sample.hurl";
@@ -57,13 +60,14 @@ use super::entry;
 ///
 /// // Create an HTTP client
 /// let mut client = http::Client::new(None);
-/// let logger = Logger::new(false, false, filename, s);
+/// let mut builder = LoggerBuilder::new();
+/// let logger = builder.filename(filename).content(s).build().unwrap();
 ///
 /// // Define runner options
-/// let runner_options = runner::RunnerOptions {
-///   very_verbose: true,
-///   ..runner::RunnerOptions::default()
-/// };
+/// let runner_options = RunnerOptionsBuilder::new()
+///     .follow_location(true)
+///     .verbosity(Some(Verbosity::Verbose))
+///     .build();
 ///
 /// // set variables
 /// let mut variables = HashMap::default();
@@ -109,12 +113,14 @@ pub fn run(
         // function because entry options can modify the logger and we want the preamble
         // "Executing entry..." to be displayed based on the entry level verbosity.
         let entry_verbosity = get_entry_verbosity(entry, &runner_options.verbosity);
-        let logger = &Logger::new(
-            logger.color,
-            entry_verbosity.is_some(),
-            logger.filename,
-            logger.content,
-        );
+        let mut builder = LoggerBuilder::new();
+        let logger = builder
+            .color(logger.color)
+            .verbose(entry_verbosity.is_some())
+            .filename(logger.filename)
+            .content(logger.content)
+            .build()
+            .unwrap();
 
         if let Some(pre_entry) = runner_options.pre_entry {
             let exit = pre_entry(entry.clone());
@@ -128,8 +134,10 @@ pub fn run(
         );
         logger.debug_important(format!("Executing entry {}", entry_index).as_str());
 
+        warn_deprecated(entry, &logger);
+
         let options_result =
-            entry::get_entry_options(entry, runner_options, &mut variables, logger);
+            entry::get_entry_options(entry, runner_options, &mut variables, &logger);
         let entry_result = match &options_result {
             Ok(options) => entry::run(
                 entry,
@@ -137,7 +145,7 @@ pub fn run(
                 http_client,
                 &mut variables,
                 options,
-                logger,
+                &logger,
             ),
             Err(error) => EntryResult {
                 entry_index,
@@ -248,3 +256,68 @@ fn is_success(entries: &[EntryResult]) -> bool {
     }
     true
 }
+
+/// Logs deprecated syntax and provides alternatives.
+fn warn_deprecated(entry: &Entry, logger: &Logger) {
+    // HTTP/* is used instead of HTTP.
+    if let Some(response) = &entry.response {
+        let version = &response.version;
+        let source_info = &version.source_info;
+        let line = &source_info.start.line;
+        let column = &source_info.start.column;
+        if version.value == VersionAnyLegacy {
+            logger.warning(
+                format!(
+                    "{}:{}:{} 'HTTP/*' keyword is deprecated, please use 'HTTP' instead",
+                    logger.filename, line, column
+                )
+                .as_str(),
+            );
+        }
+    }
+
+    // one line string with ```something``` syntax instead of `something`
+    if let Request {
+        body:
+            Some(Body {
+                value: Bytes::MultilineString(MultilineString::OneLineText(template)),
+                ..
+            }),
+        ..
+    } = &entry.request
+    {
+        let source_info = &template.source_info;
+        let line = &source_info.start.line;
+        let column = &source_info.start.column;
+        let template = template.to_string();
+        logger.warning(
+            format!(
+                "{}:{}:{} '```{}```' request body is deprecated, please use '`{}`' instead",
+                logger.filename, line, column, template, template
+            )
+            .as_str(),
+        );
+    }
+
+    if let Some(Response {
+        body:
+            Some(Body {
+                value: Bytes::MultilineString(MultilineString::OneLineText(template)),
+                ..
+            }),
+        ..
+    }) = &entry.response
+    {
+        let source_info = &template.source_info;
+        let line = &source_info.start.line;
+        let column = &source_info.start.column;
+        let template = template.to_string();
+        logger.warning(
+            format!(
+                "{}:{}:{} '```{}```' response body is deprecated, please use '`{}`' instead",
+                logger.filename, line, column, template, template
+            )
+            .as_str(),
+        );
+    }
+}
