@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@ pub use self::core::{
     AssertResult, Call, CaptureResult, EntryResult, Error, HurlResult, RunnerError, Verbosity,
 };
 pub use self::hurl_file::run;
-pub use self::runner_options::RunnerOptions;
+pub use self::runner_options::{RunnerOptions, RunnerOptionsBuilder};
 pub use self::value::Value;
 
 mod assert;
@@ -40,10 +40,12 @@ mod expr;
 mod filter;
 mod hurl_file;
 mod json;
+mod multiline;
 mod multipart;
 mod predicate;
 mod predicate_value;
 mod query;
+mod regex;
 mod request;
 mod response;
 mod runner_options;
