@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,8 @@
  *
  */
 
+use base64::engine::general_purpose;
+use base64::Engine;
 use std::collections::HashMap;
 #[allow(unused)]
 use std::io::prelude::*;
@@ -30,12 +32,7 @@ use super::template::eval_template;
 use super::value::Value;
 use crate::runner::multipart::eval_multipart_param;
 
-/// Transforms an AST request to a spec request given a set of variables.
-///
-/// # Arguments
-/// * `request` - An AST request
-/// * `variables` - A set of variables for templates/expressions.
-/// * `context_dir` - The context directory
+/// Transforms an AST `request` to a spec request given a set of `variables`.
 pub fn eval_request(
     request: &Request,
     variables: &HashMap<String, Value>,
@@ -57,8 +54,8 @@ pub fn eval_request(
     if let Some(kv) = &request.basic_auth() {
         let value = eval_template(&kv.value, variables)?;
         let user_password = format!("{}:{}", kv.key.value, value);
-        let authorization = base64::encode(user_password.as_bytes());
-
+        let user_password = user_password.as_bytes();
+        let authorization = general_purpose::STANDARD.encode(user_password);
         let name = "Authorization".to_string();
         let value = format!("Basic {}", authorization);
         let header = http::Header { name, value };
@@ -108,13 +105,16 @@ pub fn eval_request(
     } else if !multipart.is_empty() {
         Some("multipart/form-data".to_string())
     } else if let Some(Body {
-        value: Bytes::Json { .. },
+        value:
+            Bytes::Json { .. }
+            | Bytes::MultilineString(MultilineString::GraphQl(..))
+            | Bytes::MultilineString(MultilineString::Json(..)),
         ..
     }) = request.body
     {
         Some("application/json".to_string())
     } else if let Some(Body {
-        value: Bytes::Xml { .. },
+        value: Bytes::Xml { .. } | Bytes::MultilineString(MultilineString::Xml(..)),
         ..
     }) = request.body
     {
@@ -175,6 +175,13 @@ fn eval_method(method: &Method) -> http::Method {
         Method::Options => http::Method::Options,
         Method::Trace => http::Method::Trace,
         Method::Patch => http::Method::Patch,
+        Method::Link => http::Method::Link,
+        Method::Unlink => http::Method::Unlink,
+        Method::Purge => http::Method::Purge,
+        Method::Lock => http::Method::Lock,
+        Method::Unlock => http::Method::Unlock,
+        Method::Propfind => http::Method::Propfind,
+        Method::View => http::Method::View,
     }
 }
 
@@ -218,7 +225,7 @@ mod tests {
                         encoded: String::from("/hello"),
                     },
                 ],
-                quotes: false,
+                delimiter: None,
                 source_info: SourceInfo::new(0, 0, 0, 0),
             },
             line_terminator0: line_terminator,
@@ -262,7 +269,7 @@ mod tests {
                     value: String::from("http://localhost:8000/querystring-params"),
                     encoded: String::from("http://localhost:8000/querystring-params"),
                 }],
-                quotes: false,
+                delimiter: None,
                 source_info: SourceInfo::new(0, 0, 0, 0),
             },
             line_terminator0: line_terminator.clone(),
@@ -280,7 +287,7 @@ mod tests {
                             source_info: SourceInfo::new(0, 0, 0, 0),
                         },
                         Template {
-                            quotes: false,
+                            delimiter: None,
                             elements: vec![TemplateElement::Expression(Expr {
                                 space0: whitespace(),
                                 variable: Variable {
@@ -300,7 +307,7 @@ mod tests {
                             source_info: SourceInfo::new(0, 0, 0, 0),
                         },
                         Template {
-                            quotes: false,
+                            delimiter: None,
                             elements: vec![TemplateElement::String {
                                 value: "a b".to_string(),
                                 encoded: "a b".to_string(),
@@ -380,7 +387,7 @@ mod tests {
                     value: String::from("http:///localhost"),
                     encoded: String::from("http://localhost"),
                 },],
-                quotes: false,
+                delimiter: None,
                 source_info: SourceInfo::new(0, 0, 0, 0),
             },
             line_terminator0: line_terminator,
@@ -420,7 +427,7 @@ mod tests {
                         value: String::from("http:///localhost"),
                         encoded: String::from("http://localhost"),
                     },],
-                    quotes: false,
+                    delimiter: None,
                     source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 line_terminator0: line_terminator,
