@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ use std::collections::HashMap;
 
 use crate::http;
 use crate::http::ContextDir;
+use crate::runner::multiline::eval_multiline;
 use hurl_core::ast::*;
 
 use super::assert::eval_assert;
@@ -29,14 +30,36 @@ use super::json::eval_json_value;
 use super::template::eval_template;
 use super::value::Value;
 
-/// Returns a list of response assert results.
+/// Returns a list of assert results on the response status code and HTTP version,
+/// given a set of `variables`, an actual `http_response` and a spec `response`.
+pub fn eval_version_status_asserts(
+    response: &Response,
+    http_response: &http::Response,
+) -> Vec<AssertResult> {
+    let mut asserts = vec![];
+
+    let version = &response.version;
+    asserts.push(AssertResult::Version {
+        actual: http_response.version.to_string(),
+        expected: version.value.to_string(),
+        source_info: version.source_info.clone(),
+    });
+
+    let status = &response.status;
+    if let StatusValue::Specific(v) = status.value {
+        asserts.push(AssertResult::Status {
+            actual: http_response.status as u64,
+            expected: v,
+            source_info: status.source_info.clone(),
+        });
+    }
+    asserts
+}
+
+/// Returns a list of assert results, given a set of `variables`, an actual `http_response` and a spec `response`.
 ///
-/// # Arguments
-///
-/// * `response` - The spec HTTP response
-/// * `variables` - A map of input variables
-/// * `http_response` - The actual HTTP response
-/// * `context_dir` - The context directory for files
+/// Asserts on status and version and not run in this function, there are run with `eval_version_status_asserts`
+/// as they're semantically stronger.
 pub fn eval_asserts(
     response: &Response,
     variables: &HashMap<String, Value>,
@@ -45,23 +68,7 @@ pub fn eval_asserts(
 ) -> Vec<AssertResult> {
     let mut asserts = vec![];
 
-    let version = response.clone().version;
-    asserts.push(AssertResult::Version {
-        actual: http_response.version.to_string(),
-        expected: version.value.as_str().to_string(),
-        source_info: version.source_info,
-    });
-
-    let status = response.clone().status;
-    if let StatusValue::Specific(v) = status.value {
-        asserts.push(AssertResult::Status {
-            actual: http_response.status as u64,
-            expected: v as u64,
-            source_info: status.source_info,
-        });
-    }
-
-    for header in response.clone().headers {
+    for header in response.headers.iter() {
         match eval_template(&header.value, variables) {
             Err(e) => {
                 asserts.push(AssertResult::Header {
@@ -130,14 +137,7 @@ pub fn eval_asserts(
     asserts
 }
 
-/// Check the body of an actual HTTP response against a spec body.
-///
-/// # Arguments
-///
-/// * `spec_body` - The spec HTTP response body
-/// * `variables` - A map of input variables
-/// * `http_response` - The actual HTTP response
-/// * `context_dir` - The context directory for files
+/// Check the body of an actual HTTP response against a spec body, given a set of variables.
 fn eval_implicit_body_asserts(
     spec_body: &Body,
     variables: &HashMap<String, Value>,
@@ -145,7 +145,7 @@ fn eval_implicit_body_asserts(
     context_dir: &ContextDir,
 ) -> AssertResult {
     match &spec_body.value {
-        Bytes::Json { value } => {
+        Bytes::Json(value) => {
             let expected = match eval_json_value(value, variables) {
                 Ok(s) => Ok(Value::String(s)),
                 Err(e) => Err(e),
@@ -167,7 +167,7 @@ fn eval_implicit_body_asserts(
                 source_info: spec_body.space0.source_info.clone(),
             }
         }
-        Bytes::Xml { value } => {
+        Bytes::Xml(value) => {
             let expected = Ok(Value::String(value.to_string()));
             let actual = match http_response.text() {
                 Ok(s) => Ok(Value::String(s)),
@@ -186,7 +186,7 @@ fn eval_implicit_body_asserts(
                 source_info: spec_body.space0.source_info.clone(),
             }
         }
-        Bytes::RawString(RawString { value, .. }) => {
+        Bytes::OnelineString(value) => {
             let expected = match eval_template(value, variables) {
                 Ok(s) => Ok(Value::String(s)),
                 Err(e) => Err(e),
@@ -208,6 +208,28 @@ fn eval_implicit_body_asserts(
                 source_info: value.source_info.clone(),
             }
         }
+        Bytes::MultilineString(multi) => {
+            let expected = match eval_multiline(multi, variables) {
+                Ok(s) => Ok(Value::String(s)),
+                Err(e) => Err(e),
+            };
+            let actual = match http_response.text() {
+                Ok(s) => Ok(Value::String(s)),
+                Err(e) => Err(Error {
+                    source_info: SourceInfo {
+                        start: spec_body.space0.source_info.end.clone(),
+                        end: spec_body.space0.source_info.end.clone(),
+                    },
+                    inner: RunnerError::from(e),
+                    assert: true,
+                }),
+            };
+            AssertResult::Body {
+                actual,
+                expected,
+                source_info: multi.value().source_info,
+            }
+        }
         Bytes::Base64(Base64 {
             value,
             space0,
@@ -287,14 +309,18 @@ fn eval_implicit_body_asserts(
     }
 }
 
+/// Evaluates captures from this HTTP `http_response`, given a set of `variables`.
 pub fn eval_captures(
     response: &Response,
     http_response: &http::Response,
-    variables: &HashMap<String, Value>,
+    variables: &mut HashMap<String, Value>,
 ) -> Result<Vec<CaptureResult>, Error> {
     let mut captures = vec![];
     for capture in response.captures().iter() {
         let capture_result = eval_capture(capture, variables, http_response)?;
+        // Update variables now so the captures set is ready in case
+        // the next captures reference this new variable.
+        variables.insert(capture_result.name.clone(), capture_result.value.clone());
         captures.push(capture_result);
     }
     Ok(captures)
@@ -322,7 +348,7 @@ mod tests {
             line_terminators: vec![],
             version: Version {
                 value: VersionValue::Version1,
-                source_info: SourceInfo::new(2, 6, 2, 9),
+                source_info: SourceInfo::new(2, 1, 2, 9),
             },
             space0: whitespace.clone(),
             status: Status {
@@ -364,42 +390,49 @@ mod tests {
                 &http::xml_two_users_http_response(),
                 &context_dir,
             ),
+            vec![AssertResult::Explicit {
+                actual: Ok(Some(Value::Nodeset(2))),
+                source_info: SourceInfo::new(1, 14, 1, 27),
+                predicate_result: Some(Err(Error {
+                    source_info: SourceInfo::new(1, 0, 1, 0),
+                    inner: RunnerError::AssertFailure {
+                        actual: "2".to_string(),
+                        expected: "3".to_string(),
+                        type_mismatch: false,
+                    },
+                    assert: true,
+                })),
+            },]
+        );
+    }
+
+    #[test]
+    pub fn test_eval_version_status_asserts() {
+        assert_eq!(
+            eval_version_status_asserts(&user_response(), &http::xml_two_users_http_response(),),
             vec![
                 AssertResult::Version {
-                    actual: String::from("1.0"),
-                    expected: String::from("1.0"),
-                    source_info: SourceInfo::new(2, 6, 2, 9),
+                    actual: String::from("HTTP/1.0"),
+                    expected: String::from("HTTP/1.0"),
+                    source_info: SourceInfo::new(2, 1, 2, 9),
                 },
                 AssertResult::Status {
                     actual: 200,
                     expected: 200,
                     source_info: SourceInfo::new(2, 10, 2, 13),
                 },
-                AssertResult::Explicit {
-                    actual: Ok(Some(Value::Nodeset(2))),
-                    source_info: SourceInfo::new(1, 14, 1, 27),
-                    predicate_result: Some(Err(Error {
-                        source_info: SourceInfo::new(1, 0, 1, 0),
-                        inner: RunnerError::AssertFailure {
-                            actual: "2".to_string(),
-                            expected: "3".to_string(),
-                            type_mismatch: false,
-                        },
-                        assert: true,
-                    })),
-                },
             ]
         );
     }
 
     #[test]
     pub fn test_eval_captures() {
-        let variables = HashMap::new();
+        let mut variables = HashMap::new();
         assert_eq!(
             eval_captures(
                 &user_response(),
                 &http::xml_two_users_http_response(),
-                &variables,
+                &mut variables,
             )
             .unwrap(),
             vec![CaptureResult {
