@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,11 +16,11 @@
  *
  */
 
-use hurl::cli::Logger;
 use std::default::Default;
 use std::time::Duration;
 
 use hurl::http::*;
+use hurl::util::logger::LoggerBuilder;
 
 pub fn new_header(name: &str, value: &str) -> Header {
     Header {
@@ -50,7 +50,9 @@ fn test_hello() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("http://localhost:8000/hello");
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
@@ -95,7 +97,8 @@ fn test_put() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
     let request_spec = RequestSpec {
         method: Method::Put,
         url: "http://localhost:8000/put".to_string(),
@@ -109,7 +112,7 @@ fn test_put() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/put' -X PUT".to_string()
+        "curl -X PUT 'http://localhost:8000/put'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -133,7 +136,8 @@ fn test_patch() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
     let request_spec = RequestSpec {
         method: Method::Patch,
         url: "http://localhost:8000/patch/file.txt".to_string(),
@@ -160,7 +164,7 @@ fn test_patch() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/patch/file.txt' -X PATCH -H 'Host: www.example.com' -H 'Content-Type: application/example' -H 'If-Match: \"e0023aa4e\"'".to_string()
+        "curl -X PATCH -H 'Host: www.example.com' -H 'Content-Type: application/example' -H 'If-Match: \"e0023aa4e\"' 'http://localhost:8000/patch/file.txt'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -191,7 +195,9 @@ fn test_custom_headers() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Get,
         url: "http://localhost:8000/custom-headers".to_string(),
@@ -212,7 +218,7 @@ fn test_custom_headers() {
     assert!(options.curl_args().is_empty());
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/custom-headers' -H 'Fruit: Raspberry' -H 'Fruit: Apple' -H 'Fruit: Banana' -H 'Fruit: Grape' -H 'Color: Green'".to_string()
+        "curl -H 'Fruit: Raspberry' -H 'Fruit: Apple' -H 'Fruit: Banana' -H 'Fruit: Grape' -H 'Color: Green' 'http://localhost:8000/custom-headers'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -238,7 +244,9 @@ fn test_querystring_params() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Get,
         url: "http://localhost:8000/querystring-params".to_string(),
@@ -260,6 +268,10 @@ fn test_querystring_params() {
                 name: "param4".to_string(),
                 value: "1,2,3".to_string(),
             },
+            Param {
+                name: "$top".to_string(),
+                value: "5".to_string(),
+            },
         ],
         form: vec![],
         multipart: vec![],
@@ -269,11 +281,11 @@ fn test_querystring_params() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/querystring-params?param1=value1&param2=&param3=a%3Db&param4=1%2C2%2C3'".to_string()
+        "curl 'http://localhost:8000/querystring-params?param1=value1&param2=&param3=a%3Db&param4=1%2C2%2C3&$top=5'".to_string()
     );
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
     assert_eq!(request.method, "GET".to_string());
-    assert_eq!(request.url, "http://localhost:8000/querystring-params?param1=value1&param2=&param3=a%3Db&param4=1%2C2%2C3".to_string());
+    assert_eq!(request.url, "http://localhost:8000/querystring-params?param1=value1&param2=&param3=a%3Db&param4=1%2C2%2C3&$top=5".to_string());
     assert_eq!(request.headers.len(), 3);
 
     assert_eq!(response.status, 200);
@@ -289,7 +301,9 @@ fn test_form_params() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Post,
         url: "http://localhost:8000/form-params".to_string(),
@@ -328,7 +342,7 @@ fn test_form_params() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/form-params' --data 'param1=value1' --data 'param2=' --data 'param3=a%3Db' --data 'param4=a%253db' --data 'values[0]=0' --data 'values[1]=1'".to_string()
+        "curl --data 'param1=value1' --data 'param2=' --data 'param3=a%3Db' --data 'param4=a%253db' --data 'values[0]=0' --data 'values[1]=1' 'http://localhost:8000/form-params'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -359,7 +373,9 @@ fn test_form_params() {
 #[test]
 fn test_redirect() {
     let request_spec = default_get_request("http://localhost:8000/redirect-absolute");
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let options = ClientOptions::default();
     let mut client = Client::new(None);
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -385,7 +401,9 @@ fn test_redirect() {
 #[test]
 fn test_follow_location() {
     let request_spec = default_get_request("http://localhost:8000/redirect-absolute");
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let options = ClientOptions {
         follow_location: true,
         ..Default::default()
@@ -395,7 +413,7 @@ fn test_follow_location() {
     assert_eq!(options.curl_args(), vec!["-L".to_string()]);
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/redirect-absolute' -L".to_string()
+        "curl -L 'http://localhost:8000/redirect-absolute'".to_string()
     );
 
     let calls = client
@@ -452,12 +470,13 @@ fn test_max_redirect() {
     };
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
 
     let request_spec = default_get_request("http://localhost:8000/redirect/15");
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/redirect/15' -L --max-redirs 10".to_string()
+        "curl -L --max-redirs 10 'http://localhost:8000/redirect/15'".to_string()
     );
     let error = client
         .execute_with_redirect(&request_spec, &options, &logger)
@@ -468,7 +487,7 @@ fn test_max_redirect() {
     let request_spec = default_get_request("http://localhost:8000/redirect/8");
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/redirect/8' -L --max-redirs 10".to_string()
+        "curl -L --max-redirs 10 'http://localhost:8000/redirect/8'".to_string()
     );
     let calls = client
         .execute_with_redirect(&request_spec, &options, &logger)
@@ -488,7 +507,9 @@ fn test_multipart_form_data() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Post,
         url: "http://localhost:8000/multipart-form-data".to_string(),
@@ -525,7 +546,7 @@ fn test_multipart_form_data() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/multipart-form-data' -F 'key1=value1' -F 'upload1=@data.txt;type=text/plain' -F 'upload2=@data.html;type=text/html' -F 'upload3=@data.txt;type=text/html'".to_string()
+        "curl -F 'key1=value1' -F 'upload1=@data.txt;type=text/plain' -F 'upload2=@data.html;type=text/html' -F 'upload3=@data.txt;type=text/html' 'http://localhost:8000/multipart-form-data'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -553,7 +574,9 @@ fn test_post_bytes() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Post,
         url: "http://localhost:8000/post-base64".to_string(),
@@ -567,7 +590,7 @@ fn test_post_bytes() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/post-base64' -H 'Content-Type: application/octet-stream' --data $'\\x48\\x65\\x6c\\x6c\\x6f\\x20\\x57\\x6f\\x72\\x6c\\x64\\x21'".to_string()
+        "curl -H 'Content-Type: application/octet-stream' --data $'\\x48\\x65\\x6c\\x6c\\x6f\\x20\\x57\\x6f\\x72\\x6c\\x64\\x21' 'http://localhost:8000/post-base64'".to_string()
     );
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
     assert!(request.headers.contains(&Header {
@@ -586,7 +609,9 @@ fn test_expect() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Post,
         url: "http://localhost:8000/expect".to_string(),
@@ -603,7 +628,7 @@ fn test_expect() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/expect' -H 'Expect: 100-continue' -H 'Content-Type:' --data 'data'".to_string()
+        "curl -H 'Expect: 100-continue' -H 'Content-Type:' --data 'data' 'http://localhost:8000/expect'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -624,7 +649,9 @@ fn test_basic_authentication() {
     };
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Get,
         url: "http://localhost:8000/basic-authentication".to_string(),
@@ -638,7 +665,7 @@ fn test_basic_authentication() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/basic-authentication' --user 'bob@email.com:secret'"
+        "curl --user 'bob@email.com:secret' 'http://localhost:8000/basic-authentication'"
             .to_string()
     );
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -680,11 +707,13 @@ fn test_basic_authentication() {
 #[test]
 fn test_cacert() {
     let options = ClientOptions {
-        cacert_file: Some("tests/cert.pem".to_string()),
+        cacert_file: Some("tests/server_cert_selfsigned.pem".to_string()),
         ..Default::default()
     };
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("https://localhost:8001/hello");
     let (_, response) = client.execute(&request_spec, &options, &logger).unwrap();
     assert_eq!(response.status, 200);
@@ -696,7 +725,9 @@ fn test_cacert() {
 fn test_error_could_not_resolve_host() {
     let options = ClientOptions::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("http://unknown");
     let error = client
         .execute(&request_spec, &options, &logger)
@@ -719,7 +750,9 @@ fn test_error_could_not_resolve_host() {
 fn test_error_fail_to_connect() {
     let options = ClientOptions::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("http://localhost:9999");
     let error = client
         .execute(&request_spec, &options, &logger)
@@ -765,7 +798,9 @@ fn test_error_could_not_resolve_proxy_name() {
         ..Default::default()
     };
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("http://localhost:8000/hello");
     let error = client
         .execute(&request_spec, &options, &logger)
@@ -788,7 +823,9 @@ fn test_error_could_not_resolve_proxy_name() {
 fn test_error_ssl() {
     let options = ClientOptions::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("https://localhost:8001/hello");
     let error = client
         .execute(&request_spec, &options, &logger)
@@ -800,18 +837,26 @@ fn test_error_ssl() {
         url,
     } = error
     {
+        // libcurl on linux and mac exists with 60
+        // libcurl with openssl3 feature builded by vcpkg on x64-windows exists with 35
         assert_eq!(code, 60);
         let descriptions = [
+
             // Windows 2000 github runner messages:
             "schannel: SEC_E_UNTRUSTED_ROOT (0x80090325) - The certificate chain was issued by an authority that is not trusted.".to_string(),
             // Windows 10 Enterprise 2009 10.0.19041.1806
             "schannel: SEC_E_UNTRUSTED_ROOT (0x80090325)".to_string(),
             // Unix-like, before OpenSSL 3.0.0
-            "SSL certificate problem: self signed certificate".to_string(),
+            "SSL certificate problem: self signed certificate in certificate chain".to_string(),
             // Unix-like, after OpenSSL 3.0.0
             "SSL certificate problem: self-signed certificate".to_string(),
+            "SSL certificate problem: self signed certificate".to_string(),
         ];
-        assert!(descriptions.contains(&description));
+        assert!(
+            descriptions.contains(&description),
+            "actual description is {}",
+            description
+        );
         assert_eq!(url, "https://localhost:8001/hello");
     }
 }
@@ -823,7 +868,9 @@ fn test_timeout() {
         ..Default::default()
     };
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("http://localhost:8000/timeout");
     let error = client
         .execute(&request_spec, &options, &logger)
@@ -849,7 +896,8 @@ fn test_accept_encoding() {
         ..Default::default()
     };
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
 
     let request_spec = RequestSpec {
         method: Method::Get,
@@ -882,11 +930,13 @@ fn test_connect_timeout() {
     };
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("http://10.0.0.0");
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://10.0.0.0' --connect-timeout 1".to_string()
+        "curl --connect-timeout 1 'http://10.0.0.0'".to_string()
     );
     let error = client
         .execute(&request_spec, &options, &logger)
@@ -924,7 +974,9 @@ fn test_cookie() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Get,
         url: "http://localhost:8000/cookies/set-request-cookie1-valueA".to_string(),
@@ -941,7 +993,7 @@ fn test_cookie() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/cookies/set-request-cookie1-valueA' --cookie 'cookie1=valueA'"
+        "curl --cookie 'cookie1=valueA' 'http://localhost:8000/cookies/set-request-cookie1-valueA'"
             .to_string()
     );
 
@@ -975,7 +1027,9 @@ fn test_multiple_request_cookies() {
     let options = ClientOptions::default();
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Get,
         url: "http://localhost:8000/cookies/set-multiple-request-cookies".to_string(),
@@ -1002,7 +1056,7 @@ fn test_multiple_request_cookies() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/cookies/set-multiple-request-cookies' --cookie 'user1=Bob; user2=Bill; user3=Bruce'".to_string()
+        "curl --cookie 'user1=Bob; user2=Bill; user3=Bruce' 'http://localhost:8000/cookies/set-multiple-request-cookies'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -1018,7 +1072,9 @@ fn test_multiple_request_cookies() {
 fn test_cookie_storage() {
     let options = ClientOptions::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec =
         default_get_request("http://localhost:8000/cookies/set-session-cookie2-valueA");
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -1063,12 +1119,14 @@ fn test_cookie_file() {
     };
     let context_dir = ContextDir::default();
     let mut client = Client::new(Some("tests/cookies.txt".to_string()));
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec =
         default_get_request("http://localhost:8000/cookies/assert-that-cookie2-is-valueA");
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/cookies/assert-that-cookie2-is-valueA' --cookie tests/cookies.txt".to_string()
+        "curl --cookie tests/cookies.txt 'http://localhost:8000/cookies/assert-that-cookie2-is-valueA'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -1098,11 +1156,13 @@ fn test_proxy() {
     };
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = default_get_request("http://localhost:8000/proxy");
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/proxy' --proxy 'localhost:8888'".to_string()
+        "curl --proxy 'localhost:8888' 'http://localhost:8000/proxy'".to_string()
     );
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
     assert_eq!(request.url, "http://localhost:8000/proxy");
@@ -1119,12 +1179,13 @@ fn test_insecure() {
     };
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
     assert_eq!(options.curl_args(), vec!["--insecure".to_string()]);
     let request_spec = default_get_request("https://localhost:8001/hello");
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'https://localhost:8001/hello' --insecure".to_string()
+        "curl --insecure 'https://localhost:8001/hello'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
@@ -1139,7 +1200,9 @@ fn test_head() {
     };
     let context_dir = ContextDir::default();
     let mut client = Client::new(None);
-    let logger = Logger::new(false, false, "", "");
+    let mut builder = LoggerBuilder::new();
+    let logger = builder.filename("").content("").build().unwrap();
+
     let request_spec = RequestSpec {
         method: Method::Head,
         url: "http://localhost:8000/head".to_string(),
@@ -1153,7 +1216,7 @@ fn test_head() {
     };
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/head' --head".to_string()
+        "curl --head 'http://localhost:8000/head'".to_string()
     );
 
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
