@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -138,6 +138,13 @@ pub enum Method {
     Options,
     Trace,
     Patch,
+    Link,
+    Unlink,
+    Purge,
+    Lock,
+    Unlock,
+    Propfind,
+    View,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -152,17 +159,7 @@ pub enum VersionValue {
     Version11,
     Version2,
     VersionAny,
-}
-
-impl VersionValue {
-    pub fn as_str<'a>(&self) -> &'a str {
-        match self {
-            VersionValue::Version1 => "1.0",
-            VersionValue::Version11 => "1.1",
-            VersionValue::Version2 => "2",
-            VersionValue::VersionAny => "*",
-        }
-    }
+    VersionAnyLegacy,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -410,7 +407,7 @@ pub struct PredicateFunc {
 #[allow(clippy::large_enum_variant)]
 pub enum PredicateValue {
     String(Template),
-    Raw(RawString),
+    MultilineString(MultilineString),
     Integer(i64),
     Float(Float),
     Bool(bool),
@@ -489,13 +486,59 @@ pub enum PredicateFuncValue {
 //
 // Primitives
 //
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum MultilineString {
+    // FIXME: temporary type until we implement oneline as `foo` instead of ```foo```
+    OneLineText(Template),
+    Text(Text),
+    Json(Text),
+    Xml(Text),
+    GraphQl(GraphQl),
+}
+
+impl MultilineString {
+    pub fn lang(&self) -> &'static str {
+        match self {
+            MultilineString::OneLineText(_) | MultilineString::Text(_) => "",
+            MultilineString::Json(_) => "json",
+            MultilineString::Xml(_) => "xml",
+            MultilineString::GraphQl(_) => "graphql",
+        }
+    }
+
+    pub fn value(&self) -> Template {
+        match self {
+            MultilineString::OneLineText(template) => template.clone(),
+            MultilineString::Text(text)
+            | MultilineString::Json(text)
+            | MultilineString::Xml(text) => text.value.clone(),
+            MultilineString::GraphQl(text) => text.value.clone(),
+        }
+    }
+}
 
 #[derive(Clone, Debug, PartialEq, Eq)]
-pub struct RawString {
+pub struct Text {
+    pub space: Whitespace,
     pub newline: Whitespace,
     pub value: Template,
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct GraphQl {
+    pub space: Whitespace,
+    pub newline: Whitespace,
+    pub value: Template,
+    pub variables: Option<GraphQlVariables>,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct GraphQlVariables {
+    pub space: Whitespace,
+    pub value: json::Value,
+    pub whitespace: Whitespace,
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Base64 {
     pub space0: Whitespace,
@@ -513,13 +556,14 @@ pub struct File {
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Template {
-    pub quotes: bool,
+    pub delimiter: Option<char>,
     pub elements: Vec<TemplateElement>,
     pub source_info: SourceInfo,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum TemplateElement {
+    // TODO: explain the difference between value and encoded
     String { value: String, encoded: String },
     Expression(Expr),
 }
@@ -581,9 +625,10 @@ pub struct LineTerminator {
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum Bytes {
-    Json { value: json::Value },
-    Xml { value: String },
-    RawString(RawString),
+    Json(json::Value),
+    Xml(String),
+    MultilineString(MultilineString),
+    OnelineString(Template),
     Base64(Base64),
     File(File),
     Hex(Hex),
@@ -658,6 +703,8 @@ pub struct Variable {
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum EntryOption {
     CaCertificate(CaCertificateOption),
+    ClientCert(ClientCertOption),
+    ClientKey(ClientKeyOption),
     Compressed(CompressedOption),
     Insecure(InsecureOption),
     FollowLocation(FollowLocationOption),
@@ -700,6 +747,26 @@ pub struct CaCertificateOption {
     pub line_terminator0: LineTerminator,
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct ClientCertOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub filename: Filename,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct ClientKeyOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub filename: Filename,
+    pub line_terminator0: LineTerminator,
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct RetryOption {
     pub line_terminators: Vec<LineTerminator>,
@@ -805,11 +872,28 @@ pub struct Filter {
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum FilterValue {
-    Count {},
+    Count,
+    HtmlEscape,
+    HtmlUnescape,
+    Nth {
+        space0: Whitespace,
+        n: u64,
+    },
     Regex {
         space0: Whitespace,
         value: RegexValue,
     },
-    UrlEncode {},
-    UrlDecode {},
+    Replace {
+        space0: Whitespace,
+        old_value: RegexValue,
+        space1: Whitespace,
+        new_value: Template,
+    },
+    Split {
+        space0: Whitespace,
+        sep: Template,
+    },
+    ToInt,
+    UrlDecode,
+    UrlEncode,
 }
