@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,6 +30,13 @@ impl fmt::Display for Method {
             Method::Options => "OPTIONS",
             Method::Trace => "TRACE",
             Method::Patch => "PATCH",
+            Method::Link => "LINK",
+            Method::Unlink => "UNLINK",
+            Method::Purge => "PURGE",
+            Method::Lock => "LOCK",
+            Method::Unlock => "UNLOCK",
+            Method::Propfind => "PROPFIND",
+            Method::View => "VIEW",
         };
         write!(f, "{}", s)
     }
@@ -44,10 +51,11 @@ impl fmt::Display for Version {
 impl fmt::Display for VersionValue {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let s = match self {
-            VersionValue::Version1 => "1.0",
-            VersionValue::Version11 => "1.1",
-            VersionValue::Version2 => "2",
-            VersionValue::VersionAny => "*",
+            VersionValue::Version1 => "HTTP/1.0",
+            VersionValue::Version11 => "HTTP/1.1",
+            VersionValue::Version2 => "HTTP/2",
+            VersionValue::VersionAny => "HTTP",
+            VersionValue::VersionAnyLegacy => "HTTP/*",
         };
         write!(f, "{}", s)
     }
@@ -71,7 +79,7 @@ impl fmt::Display for StatusValue {
 impl fmt::Display for Template {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let mut buffer = String::from("");
-        for element in self.elements.clone() {
+        for element in self.elements.iter() {
             buffer.push_str(element.to_string().as_str());
         }
         write!(f, "{}", buffer)
@@ -103,7 +111,7 @@ impl fmt::Display for Expr {
 impl fmt::Display for CookiePath {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let mut buf = self.name.to_string();
-        if let Some(attribute) = self.attribute.clone() {
+        if let Some(attribute) = &self.attribute {
             let s = format!("[{}]", attribute);
             buf.push_str(s.as_str());
         }
@@ -143,6 +151,30 @@ impl fmt::Display for Regex {
     }
 }
 
+impl fmt::Display for MultilineString {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let body = match self {
+            MultilineString::OneLineText(template) => template.to_string(),
+            MultilineString::Text(text)
+            | MultilineString::Json(text)
+            | MultilineString::Xml(text) => text.value.to_string(),
+            MultilineString::GraphQl(graphql) => {
+                let var = match &graphql.variables {
+                    None => "".to_string(),
+                    Some(var) => {
+                        format!(
+                            "variables{}{}{}",
+                            var.space.value, var.value, var.whitespace.value
+                        )
+                    }
+                };
+                format!("{}{}", graphql.value, var)
+            }
+        };
+        write!(f, "{}", body)
+    }
+}
+
 impl PredicateFuncValue {
     pub fn name(&self) -> String {
         match self {
@@ -228,7 +260,7 @@ mod tests {
 
     fn hello_template() -> Template {
         Template {
-            quotes: false,
+            delimiter: None,
             elements: vec![
                 TemplateElement::String {
                     value: "Hello ".to_string(),
@@ -290,7 +322,7 @@ mod tests {
         assert_eq!(
             CookiePath {
                 name: Template {
-                    quotes: false,
+                    delimiter: None,
                     elements: vec![TemplateElement::String {
                         value: "LSID".to_string(),
                         encoded: "unused".to_string(),
