@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,14 +16,14 @@
  *
  */
 use super::core::Template;
-use crate::ast::{Expr, JsonValue, TemplateElement};
+use crate::ast::{Expr, TemplateElement};
 use core::fmt;
 
 ///
-/// This the AST for the JSON used within hurl
+/// This the AST for the JSON used within Hurl
 ///
 /// It is a superset of the standard json spec.
-/// Strings have been replaced by hurl template.
+/// Strings have been replaced by Hurl template.
 ///
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum Value {
@@ -73,7 +73,7 @@ pub struct ObjectElement {
     pub space3: String,
 }
 
-impl fmt::Display for JsonValue {
+impl fmt::Display for Value {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let s = match self {
             Value::Expression(expr) => format!("{{{{{}}}}}", expr),
@@ -132,7 +132,7 @@ impl fmt::Display for ObjectElement {
     }
 }
 
-impl JsonValue {
+impl Value {
     pub fn encoded(&self) -> String {
         match self {
             Value::Expression(expr) => format!("{{{{{}}}}}", expr),
@@ -191,13 +191,13 @@ impl ObjectElement {
 impl Template {
     fn encoded(&self) -> String {
         let mut s = "".to_string();
-        if self.quotes {
-            s.push('"')
+        if let Some(d) = self.delimiter {
+            s.push(d)
         }
         let elements: Vec<String> = self.elements.iter().map(|e| e.encoded()).collect();
         s.push_str(elements.join("").as_str());
-        if self.quotes {
-            s.push('"')
+        if let Some(d) = self.delimiter {
+            s.push(d)
         }
         s
     }
@@ -221,7 +221,7 @@ mod tests {
     fn test_to_string() {
         assert_eq!(
             "{{x}}".to_string(),
-            JsonValue::Expression(Expr {
+            Value::Expression(Expr {
                 space0: Whitespace {
                     value: "".to_string(),
                     source_info: SourceInfo::new(0, 0, 0, 0),
@@ -237,14 +237,11 @@ mod tests {
             })
             .to_string()
         );
-        assert_eq!(
-            "1".to_string(),
-            JsonValue::Number("1".to_string()).to_string()
-        );
+        assert_eq!("1".to_string(), Value::Number("1".to_string()).to_string());
         assert_eq!(
             "\"hello\"".to_string(),
-            JsonValue::String(Template {
-                quotes: false,
+            Value::String(Template {
+                delimiter: None,
                 elements: vec![TemplateElement::String {
                     value: "hello".to_string(),
                     encoded: "hello".to_string(),
@@ -253,10 +250,10 @@ mod tests {
             })
             .to_string()
         );
-        assert_eq!("true".to_string(), JsonValue::Boolean(true).to_string());
+        assert_eq!("true".to_string(), Value::Boolean(true).to_string());
         assert_eq!(
             "[]".to_string(),
-            JsonValue::List {
+            Value::List {
                 space0: "".to_string(),
                 elements: vec![],
             }
@@ -264,22 +261,22 @@ mod tests {
         );
         assert_eq!(
             "[1, 2, 3]".to_string(),
-            JsonValue::List {
+            Value::List {
                 space0: "".to_string(),
                 elements: vec![
                     ListElement {
                         space0: "".to_string(),
-                        value: JsonValue::Number("1".to_string()),
+                        value: Value::Number("1".to_string()),
                         space1: "".to_string(),
                     },
                     ListElement {
                         space0: " ".to_string(),
-                        value: JsonValue::Number("2".to_string()),
+                        value: Value::Number("2".to_string()),
                         space1: "".to_string(),
                     },
                     ListElement {
                         space0: " ".to_string(),
-                        value: JsonValue::Number("3".to_string()),
+                        value: Value::Number("3".to_string()),
                         space1: "".to_string(),
                     }
                 ],
@@ -288,7 +285,7 @@ mod tests {
         );
         assert_eq!(
             "{}".to_string(),
-            JsonValue::Object {
+            Value::Object {
                 space0: "".to_string(),
                 elements: vec![],
             }
@@ -296,12 +293,12 @@ mod tests {
         );
         assert_eq!(
             "{ \"id\": 123 }".to_string(),
-            JsonValue::Object {
+            Value::Object {
                 space0: "".to_string(),
                 elements: vec![ObjectElement {
                     space0: " ".to_string(),
                     name: Template {
-                        quotes: true,
+                        delimiter: Some('"'),
                         elements: vec![TemplateElement::String {
                             value: "id".to_string(),
                             encoded: "id".to_string(),
@@ -310,13 +307,13 @@ mod tests {
                     },
                     space1: "".to_string(),
                     space2: " ".to_string(),
-                    value: JsonValue::Number("123".to_string()),
+                    value: Value::Number("123".to_string()),
                     space3: " ".to_string(),
                 }],
             }
             .to_string()
         );
-        assert_eq!("null".to_string(), JsonValue::Null {}.to_string());
+        assert_eq!("null".to_string(), Value::Null {}.to_string());
     }
 
     #[test]
@@ -341,7 +338,7 @@ mod tests {
         );
         assert_eq!(
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![TemplateElement::Expression(Expr {
                     space0: Whitespace {
                         value: "".to_string(),
