@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -71,7 +71,7 @@ fn predicate_func(reader: &mut Reader) -> ParseResult<'static, PredicateFunc> {
 fn predicate_func_value(reader: &mut Reader) -> ParseResult<'static, PredicateFuncValue> {
     let start = reader.state.clone();
     match choice(
-        vec![
+        &[
             equal_predicate,
             not_equal_predicate,
             greater_or_equal_predicate,
@@ -507,7 +507,7 @@ mod tests {
             equal_predicate(&mut reader).unwrap(),
             PredicateFuncValue::Equal {
                 value: PredicateValue::String(Template {
-                    quotes: true,
+                    delimiter: Some('"'),
                     elements: vec![TemplateElement::String {
                         value: "Bob".to_string(),
                         encoded: "Bob".to_string(),
