@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,6 @@ use super::error::*;
 use super::filename;
 use super::reader::Reader;
 use super::string::*;
-use super::template;
 use super::ParseResult;
 
 pub fn space(reader: &mut Reader) -> ParseResult<'static, Whitespace> {
@@ -502,60 +501,6 @@ pub fn float(reader: &mut Reader) -> ParseResult<'static, Float> {
     Ok(Float { value, encoded })
 }
 
-pub fn raw_string(reader: &mut Reader) -> ParseResult<'static, RawString> {
-    // one value without newline or multiline mode
-    // includes the last newline (consistent with bash EOL)
-    try_literal("```", reader)?;
-    let save = reader.state.clone();
-    match newline(reader) {
-        Ok(newline) => {
-            let value = raw_string_value(reader)?;
-            Ok(RawString { newline, value })
-        }
-        Err(_) => {
-            reader.state = save;
-            let newline = Whitespace {
-                value: String::from(""),
-                source_info: SourceInfo {
-                    start: reader.state.clone().pos,
-                    end: reader.state.clone().pos,
-                },
-            };
-            let value = raw_string_value(reader)?;
-            Ok(RawString { newline, value })
-        }
-    }
-}
-
-pub fn raw_string_value(reader: &mut Reader) -> ParseResult<'static, Template> {
-    let mut chars = vec![];
-
-    let start = reader.state.pos.clone();
-    while !reader.remaining().starts_with("```") && !reader.is_eof() {
-        let pos = reader.state.pos.clone();
-        let c = reader.read().unwrap();
-        chars.push((c, c.to_string(), pos));
-    }
-    let end = reader.state.pos.clone();
-    literal("```", reader)?;
-
-    let encoded_string = template::EncodedString {
-        source_info: SourceInfo {
-            start: start.clone(),
-            end: end.clone(),
-        },
-        chars,
-    };
-
-    let elements = template::templatize(encoded_string)?;
-
-    Ok(Template {
-        quotes: false,
-        elements,
-        source_info: SourceInfo { start, end },
-    })
-}
-
 pub(crate) fn file(reader: &mut Reader) -> ParseResult<'static, File> {
     let _start = reader.state.clone();
     try_literal("file", reader)?;
@@ -833,7 +778,7 @@ mod tests {
                     source_info: SourceInfo::new(1, 9, 1, 10),
                 },
                 value: Template {
-                    quotes: false,
+                    delimiter: None,
                     elements: vec![
                         TemplateElement::String {
                             value: "hello ".to_string(),
@@ -1120,226 +1065,6 @@ mod tests {
         assert!(!error.recoverable);
     }
 
-    #[test]
-    fn test_raw_string_empty() {
-        let mut reader = Reader::init("``````");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from(""),
-                    source_info: SourceInfo::new(1, 4, 1, 4),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![],
-                    source_info: SourceInfo::new(1, 4, 1, 4),
-                },
-            }
-        );
-
-        let mut reader = Reader::init("```\n```");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from("\n"),
-                    source_info: SourceInfo::new(1, 4, 2, 1),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![],
-                    source_info: SourceInfo::new(2, 1, 2, 1),
-                },
-            }
-        );
-        let mut reader = Reader::init("```\r\n```");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from("\r\n"),
-                    source_info: SourceInfo::new(1, 4, 2, 1),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![],
-                    source_info: SourceInfo::new(2, 1, 2, 1),
-                },
-            }
-        );
-    }
-
-    #[test]
-    fn test_raw_string_hello() {
-        let mut reader = Reader::init("```Hello World!```");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from(""),
-                    source_info: SourceInfo::new(1, 4, 1, 4),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![TemplateElement::String {
-                        value: "Hello World!".to_string(),
-                        encoded: "Hello World!".to_string(),
-                    }],
-                    source_info: SourceInfo::new(1, 4, 1, 16),
-                },
-            }
-        );
-        let mut reader = Reader::init("```Hello\nWorld!\n```");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from(""),
-                    source_info: SourceInfo::new(1, 4, 1, 4),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![TemplateElement::String {
-                        value: "Hello\nWorld!\n".to_string(),
-                        encoded: "Hello\nWorld!\n".to_string(),
-                    }],
-                    source_info: SourceInfo::new(1, 4, 3, 1),
-                },
-            }
-        );
-    }
-
-    #[test]
-    fn test_raw_string_csv() {
-        let mut reader = Reader::init("```\nline1\nline2\nline3\n```");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from("\n"),
-                    source_info: SourceInfo::new(1, 4, 2, 1),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![TemplateElement::String {
-                        value: "line1\nline2\nline3\n".to_string(),
-                        encoded: "line1\nline2\nline3\n".to_string(),
-                    }],
-                    source_info: SourceInfo::new(2, 1, 5, 1),
-                },
-            }
-        );
-    }
-
-    #[test]
-    fn test_raw_string_one_emptyline() {
-        // one newline
-        // the value takes the value of the newline??
-        let mut reader = Reader::init("```\n\n```");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from("\n"),
-                    source_info: SourceInfo::new(1, 4, 2, 1),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![TemplateElement::String {
-                        value: "\n".to_string(),
-                        encoded: "\n".to_string(),
-                    }],
-                    source_info: SourceInfo::new(2, 1, 3, 1),
-                },
-            }
-        );
-
-        // one cr
-        let mut reader = Reader::init("```\n\r\n````");
-        assert_eq!(
-            raw_string(&mut reader).unwrap(),
-            RawString {
-                newline: Whitespace {
-                    value: String::from("\n"),
-                    source_info: SourceInfo::new(1, 4, 2, 1),
-                },
-                value: Template {
-                    quotes: false,
-                    elements: vec![TemplateElement::String {
-                        value: "\r\n".to_string(),
-                        encoded: "\r\n".to_string(),
-                    }],
-                    source_info: SourceInfo::new(2, 1, 3, 1),
-                },
-            }
-        );
-    }
-
-    #[test]
-    fn test_raw_string_error() {
-        let mut reader = Reader::init("xxx");
-        let error = raw_string(&mut reader).err().unwrap();
-        assert_eq!(error.pos, Pos { line: 1, column: 1 });
-        assert_eq!(
-            error.inner,
-            ParseError::Expecting {
-                value: String::from("```")
-            }
-        );
-        assert!(error.recoverable);
-
-        let mut reader = Reader::init("```\nxxx");
-        let error = raw_string(&mut reader).err().unwrap();
-        assert_eq!(error.pos, Pos { line: 2, column: 4 });
-        assert_eq!(
-            error.inner,
-            ParseError::Expecting {
-                value: String::from("```")
-            }
-        );
-        assert!(!error.recoverable);
-
-        let mut reader = Reader::init("```xxx");
-        let error = raw_string(&mut reader).err().unwrap();
-        assert_eq!(error.pos, Pos { line: 1, column: 7 });
-        assert_eq!(
-            error.inner,
-            ParseError::Expecting {
-                value: String::from("```")
-            }
-        );
-        assert!(!error.recoverable);
-    }
-
-    #[test]
-    fn test_raw_string_value() {
-        let mut reader = Reader::init("```");
-        assert_eq!(
-            raw_string_value(&mut reader).unwrap(),
-            Template {
-                quotes: false,
-                elements: vec![],
-                source_info: SourceInfo::new(1, 1, 1, 1),
-            }
-        );
-        assert_eq!(reader.state.cursor, 3);
-
-        let mut reader = Reader::init("hello```");
-        assert_eq!(
-            raw_string_value(&mut reader).unwrap(),
-            Template {
-                quotes: false,
-                elements: vec![TemplateElement::String {
-                    value: "hello".to_string(),
-                    encoded: "hello".to_string(),
-                }],
-                source_info: SourceInfo::new(1, 1, 1, 6),
-            }
-        );
-        assert_eq!(reader.state.cursor, 8);
-    }
-
     #[test]
     fn test_hex_digit() {
         let mut reader = Reader::init("0");
