@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -347,8 +347,10 @@ fn assert(reader: &mut Reader) -> ParseResult<'static, Assert> {
 
 fn option(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
     choice(
-        vec![
+        &[
             option_cacert,
+            option_cert,
+            option_key,
             option_compressed,
             option_insecure,
             option_follow_location,
@@ -386,6 +388,50 @@ fn option_cacert(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
     Ok(EntryOption::CaCertificate(option))
 }
 
+fn option_cert(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+    let line_terminators = optional_line_terminators(reader)?;
+    let space0 = zero_or_more_spaces(reader)?;
+    try_literal("cert", reader)?;
+    let space1 = zero_or_more_spaces(reader)?;
+    try_literal(":", reader)?;
+    let space2 = zero_or_more_spaces(reader)?;
+    let f = filename::parse(reader)?;
+    let line_terminator0 = line_terminator(reader)?;
+
+    let option = ClientCertOption {
+        line_terminators,
+        space0,
+        space1,
+        space2,
+        filename: f,
+        line_terminator0,
+    };
+
+    Ok(EntryOption::ClientCert(option))
+}
+
+fn option_key(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+    let line_terminators = optional_line_terminators(reader)?;
+    let space0 = zero_or_more_spaces(reader)?;
+    try_literal("key", reader)?;
+    let space1 = zero_or_more_spaces(reader)?;
+    try_literal(":", reader)?;
+    let space2 = zero_or_more_spaces(reader)?;
+    let f = filename::parse(reader)?;
+    let line_terminator0 = line_terminator(reader)?;
+
+    let option = ClientKeyOption {
+        line_terminators,
+        space0,
+        space1,
+        space2,
+        filename: f,
+        line_terminator0,
+    };
+
+    Ok(EntryOption::ClientKey(option))
+}
+
 fn option_compressed(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
     let line_terminators = optional_line_terminators(reader)?;
     let space0 = zero_or_more_spaces(reader)?;
@@ -595,7 +641,7 @@ fn variable_name(reader: &mut Reader) -> ParseResult<'static, String> {
 
 fn variable_value(reader: &mut Reader) -> ParseResult<'static, VariableValue> {
     choice(
-        vec![
+        &[
             |p1| match null(p1) {
                 Ok(()) => Ok(VariableValue::Null {}),
                 Err(e) => Err(e),
@@ -725,7 +771,7 @@ mod tests {
                                 source_info: SourceInfo::new(2, 7, 2, 8),
                             },
                             name: Template {
-                                quotes: true,
+                                delimiter: Some('"'),
                                 elements: vec![TemplateElement::String {
                                     value: "Location".to_string(),
                                     encoded: "Location".to_string(),
@@ -753,7 +799,7 @@ mod tests {
                                     source_info: SourceInfo::new(2, 25, 2, 26),
                                 },
                                 value: PredicateValue::String(Template {
-                                    quotes: true,
+                                    delimiter: Some('"'),
                                     elements: vec![TemplateElement::String {
                                         value: "https://google.fr".to_string(),
                                         encoded: "https://google.fr".to_string(),
@@ -815,7 +861,7 @@ mod tests {
         assert_eq!(
             c.value,
             Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![TemplateElement::String {
                     value: "Bar".to_string(),
                     encoded: "Bar".to_string(),
@@ -1027,7 +1073,7 @@ mod tests {
         assert_eq!(
             variable_value(&mut reader).unwrap(),
             VariableValue::String(Template {
-                quotes: false,
+                delimiter: None,
                 elements: vec![TemplateElement::String {
                     value: "toto".to_string(),
                     encoded: "toto".to_string(),
@@ -1042,7 +1088,7 @@ mod tests {
         assert_eq!(
             variable_value(&mut reader).unwrap(),
             VariableValue::String(Template {
-                quotes: true,
+                delimiter: Some('"'),
                 elements: vec![TemplateElement::String {
                     value: "123".to_string(),
                     encoded: "123".to_string(),
@@ -1173,7 +1219,7 @@ mod tests {
                         source_info: SourceInfo::new(1, 12, 1, 13),
                     },
                     name: Template {
-                        quotes: true,
+                        delimiter: Some('"'),
                         elements: vec![TemplateElement::String {
                             value: "Location".to_string(),
                             encoded: "Location".to_string(),
@@ -1200,7 +1246,7 @@ mod tests {
                         source_info: SourceInfo::new(1, 14, 1, 15),
                     },
                     name: Template {
-                        quotes: true,
+                        delimiter: Some('"'),
                         elements: vec![TemplateElement::String {
                             value: "Location".to_string(),
                             encoded: "Location".to_string(),
@@ -1265,7 +1311,7 @@ mod tests {
                         source_info: SourceInfo::new(1, 7, 1, 8),
                     },
                     name: Template {
-                        quotes: true,
+                        delimiter: Some('"'),
                         elements: vec![TemplateElement::String {
                             value: "Location".to_string(),
                             encoded: "Location".to_string(),
