@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,9 +16,13 @@
  *
  */
 
-use super::serialize_json::*;
+use base64::engine::general_purpose;
+use base64::Engine;
+
 use hurl_core::ast::*;
 
+use super::serialize_json::*;
+
 pub fn format(hurl_file: HurlFile) -> String {
     hurl_file.to_json().format()
 }
@@ -39,7 +43,7 @@ impl ToJson for HurlFile {
 impl ToJson for Entry {
     fn to_json(&self) -> JValue {
         let mut attributes = vec![("request".to_string(), self.request.to_json())];
-        if let Some(response) = self.response.clone() {
+        if let Some(response) = &self.response {
             attributes.push(("response".to_string(), response.to_json()));
         }
         JValue::Object(attributes)
@@ -55,40 +59,33 @@ impl ToJson for Request {
             ),
             ("url".to_string(), JValue::String(self.url.to_string())),
         ];
-        add_headers(&mut attributes, self.headers.clone());
+        add_headers(&mut attributes, &self.headers);
 
-        if !self.clone().querystring_params().is_empty() {
+        if !self.querystring_params().is_empty() {
             let params = self
-                .clone()
                 .querystring_params()
                 .iter()
                 .map(|p| p.to_json())
                 .collect();
             attributes.push(("query_string_params".to_string(), JValue::List(params)));
         }
-        if !self.clone().form_params().is_empty() {
-            let params = self
-                .clone()
-                .form_params()
-                .iter()
-                .map(|p| p.to_json())
-                .collect();
+        if !self.form_params().is_empty() {
+            let params = self.form_params().iter().map(|p| p.to_json()).collect();
             attributes.push(("form_params".to_string(), JValue::List(params)));
         }
-        if !self.clone().multipart_form_data().is_empty() {
+        if !self.multipart_form_data().is_empty() {
             let params = self
-                .clone()
                 .multipart_form_data()
                 .iter()
                 .map(|p| p.to_json())
                 .collect();
             attributes.push(("multipart_form_data".to_string(), JValue::List(params)));
         }
-        if !self.clone().cookies().is_empty() {
-            let cookies = self.clone().cookies().iter().map(|c| c.to_json()).collect();
+        if !self.cookies().is_empty() {
+            let cookies = self.cookies().iter().map(|c| c.to_json()).collect();
             attributes.push(("cookies".to_string(), JValue::List(cookies)));
         }
-        if let Some(body) = self.body.clone() {
+        if let Some(body) = &self.body {
             attributes.push(("body".to_string(), body.to_json()));
         }
         JValue::Object(attributes)
@@ -99,13 +96,13 @@ impl ToJson for Response {
     /// Transforms this response to a JSON object.
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
-        if let Some(v) = get_json_version(self.version.value.clone()) {
+        if let Some(v) = get_json_version(&self.version.value) {
             attributes.push(("version".to_string(), JValue::String(v)))
         }
         if let StatusValue::Specific(n) = self.status.value {
             attributes.push(("status".to_string(), JValue::Number(n.to_string())));
         }
-        add_headers(&mut attributes, self.headers.clone());
+        add_headers(&mut attributes, &self.headers);
         if !self.captures().is_empty() {
             let captures = self.captures().iter().map(|c| c.to_json()).collect();
             attributes.push(("captures".to_string(), JValue::List(captures)));
@@ -121,7 +118,7 @@ impl ToJson for Response {
     }
 }
 
-fn add_headers(attributes: &mut Vec<(String, JValue)>, headers: Vec<Header>) {
+fn add_headers(attributes: &mut Vec<(String, JValue)>, headers: &Vec<Header>) {
     if !headers.is_empty() {
         let headers = JValue::List(headers.iter().map(|h| h.to_json()).collect());
         attributes.push(("headers".to_string(), headers))
@@ -140,41 +137,65 @@ impl ToJson for Bytes {
             Bytes::Base64(value) => value.to_json(),
             Bytes::Hex(value) => value.to_json(),
             Bytes::File(value) => value.to_json(),
-            Bytes::Json { value } => JValue::Object(vec![
+            Bytes::Json(value) => JValue::Object(vec![
                 ("type".to_string(), JValue::String("json".to_string())),
                 ("value".to_string(), value.to_json()),
             ]),
-            Bytes::Xml { value } => JValue::Object(vec![
+            Bytes::Xml(value) => JValue::Object(vec![
                 ("type".to_string(), JValue::String("xml".to_string())),
                 ("value".to_string(), JValue::String(value.clone())),
             ]),
-            Bytes::RawString(value) => JValue::Object(vec![
-                ("type".to_string(), JValue::String("raw-string".to_string())),
-                ("value".to_string(), JValue::String(value.value.to_string())),
+            Bytes::OnelineString(value) => JValue::Object(vec![
+                ("type".to_string(), JValue::String("text".to_string())),
+                ("value".to_string(), JValue::String(value.to_string())),
             ]),
+            Bytes::MultilineString(multi) => {
+                // TODO: check these values. Maybe we want to have the same
+                // export when using:
+                //
+                // ~~~
+                // GET https://foo.com
+                // ```base64
+                // SGVsbG8gd29ybGQ=
+                // ```
+                //
+                // or
+                //
+                // ~~~
+                // GET https://foo.com
+                // base64,SGVsbG8gd29ybGQ=;
+                // ~~~
+                let lang = match multi {
+                    MultilineString::OneLineText(_) | MultilineString::Text(_) => "text",
+                    MultilineString::Json(_) => "json",
+                    MultilineString::Xml(_) => "xml",
+                    MultilineString::GraphQl(_) => "graphql",
+                };
+                JValue::Object(vec![
+                    ("type".to_string(), JValue::String(lang.to_string())),
+                    ("value".to_string(), JValue::String(multi.to_string())),
+                ])
+            }
         }
     }
 }
 
 impl ToJson for Base64 {
     fn to_json(&self) -> JValue {
+        let value = general_purpose::STANDARD.encode(&self.value);
         JValue::Object(vec![
             ("encoding".to_string(), JValue::String("base64".to_string())),
-            (
-                "value".to_string(),
-                JValue::String(base64::encode(&self.value)),
-            ),
+            ("value".to_string(), JValue::String(value)),
         ])
     }
 }
+
 impl ToJson for Hex {
     fn to_json(&self) -> JValue {
+        let value = general_purpose::STANDARD.encode(&self.value);
         JValue::Object(vec![
             ("encoding".to_string(), JValue::String("base64".to_string())),
-            (
-                "value".to_string(),
-                JValue::String(base64::encode(&self.value)),
-            ),
+            ("value".to_string(), JValue::String(value)),
         ])
     }
 }
@@ -191,12 +212,13 @@ impl ToJson for File {
     }
 }
 
-fn get_json_version(version_value: VersionValue) -> Option<String> {
+fn get_json_version(version_value: &VersionValue) -> Option<String> {
     match version_value {
         VersionValue::Version1 => Some("HTTP/1.0".to_string()),
         VersionValue::Version11 => Some("HTTP/1.1".to_string()),
         VersionValue::Version2 => Some("HTTP/2".to_string()),
         VersionValue::VersionAny => None,
+        VersionValue::VersionAnyLegacy => None,
     }
 }
 
@@ -447,19 +469,19 @@ fn add_predicate_value(attributes: &mut Vec<(String, JValue)>, predicate_value:
 fn json_predicate_value(predicate_value: PredicateValue) -> (JValue, Option<String>) {
     match predicate_value {
         PredicateValue::String(value) => (JValue::String(value.to_string()), None),
-        PredicateValue::Raw(value) => (JValue::String(value.value.to_string()), None),
+        PredicateValue::MultilineString(value) => (JValue::String(value.value().to_string()), None),
         PredicateValue::Integer(value) => (JValue::Number(value.to_string()), None),
         PredicateValue::Float(value) => (JValue::Number(value.to_string()), None),
         PredicateValue::Bool(value) => (JValue::Boolean(value), None),
         PredicateValue::Null {} => (JValue::Null, None),
-        PredicateValue::Hex(value) => (
-            JValue::String(base64::encode(&value.value)),
-            Some("base64".to_string()),
-        ),
-        PredicateValue::Base64(value) => (
-            JValue::String(base64::encode(&value.value)),
-            Some("base64".to_string()),
-        ),
+        PredicateValue::Hex(value) => {
+            let base64_string = general_purpose::STANDARD.encode(value.value);
+            (JValue::String(base64_string), Some("base64".to_string()))
+        }
+        PredicateValue::Base64(value) => {
+            let base64_string = general_purpose::STANDARD.encode(value.value);
+            (JValue::String(base64_string), Some("base64".to_string()))
+        }
         PredicateValue::Expression(value) => (JValue::String(value.to_string()), None),
         PredicateValue::Regex(value) => {
             (JValue::String(value.to_string()), Some("regex".to_string()))
@@ -467,12 +489,6 @@ fn json_predicate_value(predicate_value: PredicateValue) -> (JValue, Option<Stri
     }
 }
 
-impl ToJson for RawString {
-    fn to_json(&self) -> JValue {
-        JValue::String(self.value.to_string())
-    }
-}
-
 impl ToJson for JsonValue {
     fn to_json(&self) -> JValue {
         match self {
@@ -510,19 +526,51 @@ impl ToJson for FilterValue {
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
         match self {
+            FilterValue::Count => {
+                attributes.push(("type".to_string(), JValue::String("count".to_string())));
+            }
+            FilterValue::Nth { n, .. } => {
+                attributes.push(("type".to_string(), JValue::String("nth".to_string())));
+                attributes.push(("n".to_string(), JValue::Number(n.to_string())));
+            }
+            FilterValue::HtmlEscape => {
+                attributes.push(("type".to_string(), JValue::String("htmlEscape".to_string())));
+            }
+            FilterValue::HtmlUnescape => {
+                attributes.push((
+                    "type".to_string(),
+                    JValue::String("htmlUnescape".to_string()),
+                ));
+            }
             FilterValue::Regex { value, .. } => {
                 attributes.push(("type".to_string(), JValue::String("regex".to_string())));
                 attributes.push(("expr".to_string(), value.to_json()));
             }
-            FilterValue::Count { .. } => {
-                attributes.push(("type".to_string(), JValue::String("count".to_string())));
+            FilterValue::Replace {
+                old_value,
+                new_value,
+                ..
+            } => {
+                attributes.push(("type".to_string(), JValue::String("replace".to_string())));
+                attributes.push(("old_value".to_string(), old_value.to_json()));
+                attributes.push((
+                    "new_value".to_string(),
+                    JValue::String(new_value.to_string()),
+                ));
             }
-            FilterValue::UrlEncode { .. } => {
+            FilterValue::UrlEncode => {
                 attributes.push(("type".to_string(), JValue::String("urlEncode".to_string())));
             }
-            FilterValue::UrlDecode { .. } => {
+            FilterValue::UrlDecode => {
                 attributes.push(("type".to_string(), JValue::String("urlDecode".to_string())));
             }
+            FilterValue::Split { sep, .. } => {
+                attributes.push(("type".to_string(), JValue::String("split".to_string())));
+                attributes.push(("sep".to_string(), JValue::String(sep.to_string())));
+            }
+            FilterValue::ToInt => {
+                attributes.push(("type".to_string(), JValue::String("toInt".to_string())));
+            }
         }
         JValue::Object(attributes)
     }
@@ -556,7 +604,7 @@ pub mod tests {
                 method: Method::Get,
                 space1: whitespace(),
                 url: Template {
-                    quotes: false,
+                    delimiter: None,
                     elements: vec![TemplateElement::String {
                         value: "http://example.com".to_string(),
                         encoded: "not_used".to_string(),
@@ -576,7 +624,7 @@ pub mod tests {
                     space1: whitespace(),
                     space2: whitespace(),
                     value: Template {
-                        quotes: false,
+                        delimiter: None,
                         elements: vec![TemplateElement::String {
                             value: "Bar".to_string(),
                             encoded: "unused".to_string(),
@@ -667,7 +715,7 @@ pub mod tests {
             value: QueryValue::Header {
                 space0: whitespace(),
                 name: Template {
-                    quotes: false,
+                    delimiter: None,
                     elements: vec![TemplateElement::String {
                         value: "Content-Length".to_string(),
                         encoded: "10".to_string(),
