@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2022 Orange
+ * Copyright (C) 2023 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -35,12 +35,13 @@ pub enum Token {
     Comment(String),
     Value(String),
     Colon(String),
-    Quote(String),
+    StringDelimiter(String),
     Boolean(String),
     Number(String),
     String(String),
     CodeDelimiter(String),
     CodeVariable(String),
+    Lang(String),
 }
 
 pub trait Tokenizable {
@@ -134,15 +135,7 @@ impl Tokenizable for Status {
 
 impl Tokenizable for Version {
     fn tokenize(&self) -> Vec<Token> {
-        vec![Token::Version(format!(
-            "HTTP/{}",
-            match self.value {
-                VersionValue::Version1 => String::from("1.0"),
-                VersionValue::Version11 => String::from("1.1"),
-                VersionValue::Version2 => String::from("2"),
-                VersionValue::VersionAny => String::from("*"),
-            }
-        ))]
+        vec![Token::Version(self.value.to_string())]
     }
 }
 
@@ -167,23 +160,13 @@ impl Tokenizable for Bytes {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
         match self {
-            Bytes::Json { value } => tokens.append(&mut value.tokenize()),
-            Bytes::Xml { value } => {
-                tokens.push(Token::String(value.to_string()));
-            }
-            //            Bytes::MultilineString { value: _ } => {}
-            Bytes::RawString(value) => {
-                tokens.append(&mut value.tokenize());
-            }
-            Bytes::Base64(value) => {
-                tokens.append(&mut value.tokenize());
-            }
-            Bytes::Hex(value) => {
-                tokens.append(&mut value.tokenize());
-            }
-            Bytes::File(value) => {
-                tokens.append(&mut value.tokenize());
-            }
+            Bytes::Json(value) => tokens.append(&mut value.tokenize()),
+            Bytes::Xml(value) => tokens.push(Token::String(value.to_string())),
+            Bytes::MultilineString(value) => tokens.append(&mut value.tokenize()),
+            Bytes::OnelineString(value) => tokens.append(&mut value.tokenize()),
+            Bytes::Base64(value) => tokens.append(&mut value.tokenize()),
+            Bytes::Hex(value) => tokens.append(&mut value.tokenize()),
+            Bytes::File(value) => tokens.append(&mut value.tokenize()),
         }
         tokens
     }
@@ -598,7 +581,7 @@ impl Tokenizable for PredicateValue {
     fn tokenize(&self) -> Vec<Token> {
         match self {
             PredicateValue::String(value) => value.tokenize(),
-            PredicateValue::Raw(value) => value.tokenize(),
+            PredicateValue::MultilineString(value) => value.tokenize(),
             PredicateValue::Integer(value) => vec![Token::Number(value.to_string())],
             PredicateValue::Float(value) => vec![Token::Number(value.to_string())],
             PredicateValue::Bool(value) => vec![Token::Boolean(value.to_string())],
@@ -611,14 +594,57 @@ impl Tokenizable for PredicateValue {
     }
 }
 
-impl Tokenizable for RawString {
+impl Tokenizable for MultilineString {
     fn tokenize(&self) -> Vec<Token> {
-        let mut tokens: Vec<Token> = vec![
-            Token::Keyword("```".to_string()),
-            Token::Whitespace(self.newline.value.clone()),
-        ];
+        let mut tokens: Vec<Token> = vec![Token::StringDelimiter("```".to_string())];
+        // FIXME: ugly if !let workaround, will be removed soon as
+        // OneLineText is temporary.
+        if let MultilineString::OneLineText(..) = self {
+        } else {
+            tokens.push(Token::Lang(self.lang().to_string()));
+        }
+        match self {
+            MultilineString::OneLineText(template) => tokens.append(&mut template.tokenize()),
+            MultilineString::Text(text)
+            | MultilineString::Json(text)
+            | MultilineString::Xml(text) => tokens.append(&mut text.tokenize()),
+            MultilineString::GraphQl(graphql) => tokens.append(&mut graphql.tokenize()),
+        }
+        tokens.push(Token::StringDelimiter("```".to_string()));
+        tokens
+    }
+}
+
+impl Tokenizable for Text {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(&mut self.space.tokenize());
+        tokens.append(&mut self.newline.tokenize());
         tokens.append(&mut self.value.tokenize());
-        tokens.push(Token::Keyword("```".to_string()));
+        tokens
+    }
+}
+
+impl Tokenizable for GraphQl {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(&mut self.space.tokenize());
+        tokens.append(&mut self.newline.tokenize());
+        tokens.append(&mut self.value.tokenize());
+        if let Some(vars) = &self.variables {
+            tokens.append(&mut vars.tokenize());
+        }
+        tokens
+    }
+}
+
+impl Tokenizable for GraphQlVariables {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.push(Token::String("variables".to_string()));
+        tokens.append(&mut self.space.tokenize());
+        tokens.append(&mut self.value.tokenize());
+        tokens.append(&mut self.whitespace.tokenize());
         tokens
     }
 }
@@ -627,14 +653,14 @@ impl Tokenizable for EncodedString {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
         if self.quotes {
-            tokens.push(Token::Quote(
+            tokens.push(Token::StringDelimiter(
                 if self.clone().quotes { "\"" } else { "" }.to_string(),
             ));
         }
         tokens.push(Token::String(self.encoded.clone()));
 
         if self.quotes {
-            tokens.push(Token::Quote(
+            tokens.push(Token::StringDelimiter(
                 if self.clone().quotes { "\"" } else { "" }.to_string(),
             ));
         }
@@ -645,19 +671,14 @@ impl Tokenizable for EncodedString {
 impl Tokenizable for Template {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
-        if self.quotes {
-            tokens.push(Token::Quote(
-                if self.clone().quotes { "\"" } else { "" }.to_string(),
-            ));
+        if let Some(d) = self.delimiter {
+            tokens.push(Token::StringDelimiter(d.to_string()));
         }
         for element in self.elements.clone() {
             tokens.append(&mut element.tokenize());
         }
-
-        if self.quotes {
-            tokens.push(Token::Quote(
-                if self.clone().quotes { "\"" } else { "" }.to_string(),
-            ));
+        if let Some(d) = self.delimiter {
+            tokens.push(Token::StringDelimiter(d.to_string()));
         }
         tokens
     }
@@ -791,9 +812,9 @@ impl Tokenizable for JsonListElement {
 impl Tokenizable for JsonObjectElement {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![Token::Whitespace(self.space0.clone())];
-        tokens.push(Token::Quote("\"".to_string()));
+        tokens.push(Token::StringDelimiter("\"".to_string()));
         tokens.push(Token::String(self.name.to_string()));
-        tokens.push(Token::Quote("\"".to_string()));
+        tokens.push(Token::StringDelimiter("\"".to_string()));
         tokens.push(Token::Whitespace(self.space1.clone()));
         tokens.push(Token::CodeDelimiter(":".to_string()));
         tokens.push(Token::Whitespace(self.space2.clone()));
@@ -807,6 +828,8 @@ impl Tokenizable for EntryOption {
     fn tokenize(&self) -> Vec<Token> {
         match self {
             EntryOption::CaCertificate(option) => option.tokenize(),
+            EntryOption::ClientCert(option) => option.tokenize(),
+            EntryOption::ClientKey(option) => option.tokenize(),
             EntryOption::Compressed(option) => option.tokenize(),
             EntryOption::Insecure(option) => option.tokenize(),
             EntryOption::FollowLocation(option) => option.tokenize(),
@@ -842,6 +865,48 @@ impl Tokenizable for CaCertificateOption {
     }
 }
 
+impl Tokenizable for ClientCertOption {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(
+            &mut self
+                .line_terminators
+                .iter()
+                .flat_map(|e| e.tokenize())
+                .collect(),
+        );
+        tokens.append(&mut self.space0.tokenize());
+        tokens.push(Token::String("cert".to_string()));
+        tokens.append(&mut self.space1.tokenize());
+        tokens.push(Token::Colon(String::from(":")));
+        tokens.append(&mut self.space2.tokenize());
+        tokens.append(&mut self.filename.tokenize());
+        tokens.append(&mut self.line_terminator0.tokenize());
+        tokens
+    }
+}
+
+impl Tokenizable for ClientKeyOption {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(
+            &mut self
+                .line_terminators
+                .iter()
+                .flat_map(|e| e.tokenize())
+                .collect(),
+        );
+        tokens.append(&mut self.space0.tokenize());
+        tokens.push(Token::String("key".to_string()));
+        tokens.append(&mut self.space1.tokenize());
+        tokens.push(Token::Colon(String::from(":")));
+        tokens.append(&mut self.space2.tokenize());
+        tokens.append(&mut self.filename.tokenize());
+        tokens.append(&mut self.line_terminator0.tokenize());
+        tokens
+    }
+}
+
 impl Tokenizable for CompressedOption {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -1078,16 +1143,45 @@ impl Tokenizable for VeryVerboseOption {
 impl Tokenizable for Filter {
     fn tokenize(&self) -> Vec<Token> {
         match self.value.clone() {
+            FilterValue::Count => vec![Token::FilterType(String::from("count"))],
+            FilterValue::HtmlEscape => vec![Token::FilterType(String::from("htmlEscape"))],
+            FilterValue::HtmlUnescape => {
+                vec![Token::FilterType(String::from("htmlUnescape"))]
+            }
+            FilterValue::Nth { space0, n } => {
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("nth"))];
+                tokens.append(&mut space0.tokenize());
+                tokens.push(Token::Number(n.to_string()));
+                tokens
+            }
             FilterValue::Regex { space0, value } => {
-                let mut tokens: Vec<Token> = vec![];
-                tokens.push(Token::FilterType(String::from("regex")));
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("regex"))];
                 tokens.append(&mut space0.tokenize());
                 tokens.append(&mut value.tokenize());
                 tokens
             }
-            FilterValue::Count { .. } => vec![Token::FilterType(String::from("count"))],
-            FilterValue::UrlEncode { .. } => vec![Token::FilterType(String::from("urlEncode"))],
-            FilterValue::UrlDecode { .. } => vec![Token::FilterType(String::from("urlDecode"))],
+            FilterValue::Replace {
+                space0,
+                old_value,
+                space1,
+                new_value,
+            } => {
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("replace"))];
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut old_value.tokenize());
+                tokens.append(&mut space1.tokenize());
+                tokens.append(&mut new_value.tokenize());
+                tokens
+            }
+            FilterValue::UrlEncode => vec![Token::FilterType(String::from("urlEncode"))],
+            FilterValue::UrlDecode => vec![Token::FilterType(String::from("urlDecode"))],
+            FilterValue::Split { space0, sep } => {
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("split"))];
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut sep.tokenize());
+                tokens
+            }
+            FilterValue::ToInt => vec![Token::FilterType(String::from("toInt"))],
         }
     }
 }
